@@ -14,8 +14,9 @@ STRINGdb <- setRefClass("STRINGdb",
       #spe    ciesList="data.frame",
       species="numeric",
       version="character",
+      link_data="character",
       network_type = "character",
-      input_directory="character",
+      input_directory = "character",
       backgroundV = "vector",
       score_threshold = "numeric",
       pathways_benchmark_blackList="data.frame",
@@ -130,6 +131,15 @@ Author(s):
 
           }
 
+          if(length(link_data)==0) {
+              link_data <<- "combined_only";
+          } else {
+  
+              if (!(tolower(link_data)=="combined_only" || tolower(link_data)=="full" || tolower(link_data) == "detailed")) {
+                      cat("WARNING: Only 'combined_only', 'detailed' and 'full' link data types are valid. Setting to 'combined_only'.\n")
+                      link_data <<- "combined_only";
+              }
+          }
 
 
           curr_version_table = read.table(url(paste(protocol,"://string-db.org/api/tsv-no-header/version", sep="")), colClasses = "character")
@@ -168,7 +178,12 @@ Author(s):
           }
 
           stable_url <<- subset(version_available_table, V1==version)$V2
-         
+
+          if (tolower(protocol) == 'http') {
+              stable_url <<- gsub("https:", "http:", stable_url)
+          }         
+
+
           if(input_directory=="" || is.null(input_directory) || length(input_directory)==0) input_directory<<-tempdir()
           if(input_directory=="" || is.null(input_directory) || length(score_threshold)==0 || score_threshold<1) score_threshold <<- 1
 
@@ -467,7 +482,7 @@ Author(s):
              params = list(species=species, identifiers=identifiers, background_string_identifiers=background)
          }
  
-         tempDfv =postFormSmart(urlStr, .params=params)
+         tempDfv = postFormSmart(urlStr, .params=params)
 
          ann = read.table(text=tempDfv, sep="\t", stringsAsFactors=FALSE, quote="", fill=TRUE, header=TRUE)
 
@@ -661,13 +676,15 @@ Author(s):
         params = list(required_score=required_score, required_score=required_score, network_flavor=network_flavor, network_type=network_type_param, identifiers=identifiers, species=species, caller_identity='STRINGdb-package')
 
         if(!is.null(payload_id)) params["internal_payload_id"]= payload_id
-        img <- readPNG(postFormSmart(  urlStr, .params=params) )
+
+        img <- readPNG(postFormSmart(  urlStr, .params=params, .ctype='raw') )
         if(!is.null(file))  writePNG(img,  file)
-        
+
         return(img)
       },
  
 
+
       #########################################
       ## get_graph
       #########################################
@@ -832,11 +849,6 @@ Author(s):
 
 '
 
-        if (!(version %in% c("11.0", "11.0b"))) {
-            print("Method available only in versions 11.0 and 11.0b")
-            stop()
-        }
-
         string_ids = unique(string_ids)
         string_ids = string_ids[!is.na(string_ids)]
 
@@ -1038,8 +1050,16 @@ Author(s):
             network_type_param = 'physical.'
         }
 
+        link_data_param = "links.v";
+
+        if (tolower(link_data) == "detailed") {
+            link_data_param = "links.detailed.v";
+        } else if (tolower(link_data) == "full") {
+            link_data_param = "links.full.v";
+        }
+
+        url <- paste(protocol, "://stringdb-downloads.org/download/protein.", network_type_param, link_data_param, file_version, "/", species, ".protein.", network_type_param, link_data_param, file_version, ".txt.gz", sep="")
 
-        url <- paste(protocol, "://stringdb-downloads.org/download/protein.", network_type_param, "links.v", file_version, "/", species, ".protein.", network_type_param, "links.v", file_version, ".txt.gz", sep="")
         temp = downloadAbsentFile(url, oD=input_directory)
         PPI <- read.table(temp, sep = " ", header=TRUE, stringsAsFactors=FALSE, fill = TRUE)
         
