@@ -4,8 +4,8 @@
 ### code chunk number 1: initialization
 ###################################################
 library(STRINGdb)
-string_db <- STRINGdb$new( version="11.5", species=9606, 
-                           score_threshold=200, network_type="full", input_directory="")
+string_db <- STRINGdb$new( version="12.0", species=9606, 
+                           score_threshold=200, network_type="full", link_data='combined_only', input_directory="")
 
 
 ###################################################
@@ -139,9 +139,9 @@ atm = string_db$mp( "atm" )
 
 
 ###################################################
-### code chunk number 20: neighbors (eval = FALSE)
+### code chunk number 20: neighbors
 ###################################################
-## string_db$get_neighbors( c(tp53, atm) )
+string_db$get_neighbors( c(tp53, atm) )
 
 
 ###################################################
@@ -151,23 +151,23 @@ string_db$get_interactions( c(tp53, atm) )
 
 
 ###################################################
-### code chunk number 22: paralogs (eval = FALSE)
+### code chunk number 22: paralogs
 ###################################################
-## # Get all homologs of TP53 in human.
-## string_db$get_paralogs(tp53)
+# Get all homologs of TP53 in human.
+string_db$get_paralogs(tp53)
 
 
 ###################################################
-### code chunk number 23: Closest homologs from other species (eval = FALSE)
+### code chunk number 23: Closest homologs from other species
 ###################################################
-## # get the best hits of the following protein in all the STRING species
-## string_db$get_homologs_besthits(tp53)
+# get the best hits of the following protein in all the STRING species
+string_db$get_homologs_besthits(tp53)
 
 
 ###################################################
-### code chunk number 24: homologs_besthits in target species (eval = FALSE)
+### code chunk number 24: homologs_besthits in target species
 ###################################################
-## # get the homologs of the following two proteins in the mouse (i.e. species_id=10090)
-## string_db$get_homologs_besthits(c(tp53, atm), target_species_id=10090, bitscore_threshold=60)
+# get the homologs of the following two proteins in the mouse (i.e. species_id=10090)
+string_db$get_homologs_besthits(c(tp53, atm), target_species_id=10090)
 
 
